==> zio-aws-devicefarm_3-5.17.112.1-sources.jar: zio/aws/devicefarm/model/ScheduleRunResponse.scala <==
package zio.aws.devicefarm.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ScheduleRunResponse(
    run: Option[zio.aws.devicefarm.model.Run] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.devicefarm.model.ScheduleRunResponse = {
    import ScheduleRunResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.devicefarm.model.ScheduleRunResponse
      .builder()
      .optionallyWith(run.map(value => value.buildAwsValue()))(_.run)
      .build()
  }
  def asReadOnly: zio.aws.devicefarm.model.ScheduleRunResponse.ReadOnly =
    zio.aws.devicefarm.model.ScheduleRunResponse.wrap(buildAwsValue())
}
object ScheduleRunResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.devicefarm.model.ScheduleRunResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.devicefarm.model.ScheduleRunResponse =
      zio.aws.devicefarm.model
        .ScheduleRunResponse(run.map(value => value.asEditable))
    def run: Option[zio.aws.devicefarm.model.Run.ReadOnly]
    def getRun: ZIO[Any, AwsError, zio.aws.devicefarm.model.Run.ReadOnly] =
      AwsError.unwrapOptionField("run", run)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.devicefarm.model.ScheduleRunResponse
  ) extends zio.aws.devicefarm.model.ScheduleRunResponse.ReadOnly {
    override val run: Option[zio.aws.devicefarm.model.Run.ReadOnly] = scala
      .Option(impl.run())
      .map(value => zio.aws.devicefarm.model.Run.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.devicefarm.model.ScheduleRunResponse
  ): zio.aws.devicefarm.model.ScheduleRunResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-devicefarm_3-6.20.74.2-sources.jar: zio/aws/devicefarm/model/ScheduleRunResponse.scala <==
package zio.aws.devicefarm.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ScheduleRunResponse(
    run: Optional[zio.aws.devicefarm.model.Run] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.devicefarm.model.ScheduleRunResponse = {
    import ScheduleRunResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.devicefarm.model.ScheduleRunResponse
      .builder()
      .optionallyWith(run.map(value => value.buildAwsValue()))(_.run)
      .build()
  }
  def asReadOnly: zio.aws.devicefarm.model.ScheduleRunResponse.ReadOnly =
    zio.aws.devicefarm.model.ScheduleRunResponse.wrap(buildAwsValue())
}
object ScheduleRunResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.devicefarm.model.ScheduleRunResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.devicefarm.model.ScheduleRunResponse =
      zio.aws.devicefarm.model
        .ScheduleRunResponse(run.map(value => value.asEditable))
    def run: Optional[zio.aws.devicefarm.model.Run.ReadOnly]
    def getRun: ZIO[Any, AwsError, zio.aws.devicefarm.model.Run.ReadOnly] =
      AwsError.unwrapOptionField("run", run)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.devicefarm.model.ScheduleRunResponse
  ) extends zio.aws.devicefarm.model.ScheduleRunResponse.ReadOnly {
    override val run: Optional[zio.aws.devicefarm.model.Run.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.run())
        .map(value => zio.aws.devicefarm.model.Run.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.devicefarm.model.ScheduleRunResponse
  ): zio.aws.devicefarm.model.ScheduleRunResponse.ReadOnly = new Wrapper(impl)
}
